@@ -1,18 +1,12 @@
 from django.test import RequestFactory, TestCase
 
-import wagtail
+from wagtail.models import Site
 
 from flags.conditions import RequiredForCondition
 
 from wagtailflags.conditions import site_condition
 
 
-if wagtail.VERSION > (3, 0, 0):  # pragma: no cover
-    from wagtail.models import Site
-else:  # pragma: no cover
-    from wagtail.core.models import Site
-
-
 class SiteConditionTestCase(TestCase):
     def setUp(self):
         self.site = Site.objects.get(is_default_site=True)
